{% load i18n %}
{% load navactive %}
{% if perms.killstats.admin_access %}
<li class="nav-item">
    <a class="nav-link py-0" href="{% url 'killstats:add_corp' %}">
        <span class="btn btn-success">{% translate 'Add Corporation' %}</span>
    </a>
</li>
<li class="nav-item">
    <a class="nav-link py-0" href="{% url 'killstats:add_alliance' %}">
        <span class="btn btn-success">{% translate 'Add Alliance' %}</span>
    </a>
</li>
{% endif %}
