# Generated by Django 4.2.11 on 2024-09-26 21:34

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("eveuniverse", "0010_alter_eveindustryactivityduration_eve_type_and_more"),
        ("killstats", "0002_rename_killstatsaudit_corporationsaudit_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Attacker",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "killmail",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="attacker_killmail",
                        to="killstats.killmail",
                    ),
                ),
                ("damage_done", models.IntegerField(blank=True, null=True)),
                ("final_blow", models.BooleanField(blank=True, null=True)),
                (
                    "weapon_type_id",
                    models.PositiveBigIntegerField(blank=True, null=True),
                ),
                ("security_status", models.FloatField(blank=True, null=True)),
                (
                    "alliance",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="attacker_alliance",
                        to="eveuniverse.eveentity",
                    ),
                ),
                (
                    "character",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="attacker_character",
                        to="eveuniverse.eveentity",
                    ),
                ),
                (
                    "corporation",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="attacker_corp",
                        to="eveuniverse.eveentity",
                    ),
                ),
                (
                    "ship",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="attacker_ship",
                        to="eveuniverse.evetype",
                    ),
                ),
            ],
            options={
                "default_permissions": (),
            },
        ),
        migrations.RemoveField(
            model_name="killmail",
            name="attackers",
        ),
        migrations.AlterField(
            model_name="killmail",
            name="victim",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="eveuniverse.eveentity",
            ),
        ),
        migrations.DeleteModel(
            name="EveEntity",
        ),
    ]
