{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}
{% block main_css %}
{% endblock main_css %}
{% block extra_css %}
{% endblock extra_css %}

{% block page_title %}
    Killstats
{% endblock %}

{% block header_nav_brand %}
    <a class="nav-link text-white link-light link-underline link-underline-opacity-0" href="{% url 'killstats:index' %}">Killstats</a>
{% endblock header_nav_brand %}

{% block header_nav_collapse_left %}

{% include 'killstats/partials/menu/navigation.html' %}

{% endblock header_nav_collapse_left %}

{% block header_nav_collapse_right %}

{% include 'killstats/partials/menu/administration.html' %}

{% endblock header_nav_collapse_right %}

{% block content %}

{% include 'killstats/bundles/killstats-css.html' %}
{% include 'bundles/datatables-css-bs5.html' %}

<div class="allianceauth-killstats-plugin">
    <div class="card-killstats">
        {% block killstats_block %}

        {% endblock %}
    </div>
</div>

{% endblock content %}

{% block extra_javascript %}
{% endblock %}

{% block extra_script %}
{% endblock %}
