.custom-line {
    height: 3px;
    border: none;
    background: linear-gradient(to right, rgb(0 170 255) 0%, transparent 80%, transparent 100%);
    z-index: 1;
}

/* Style the Image Used to Trigger the Modal */
.zoom {
    opacity: 0.7;
    cursor: pointer;
    transition: 0.3s;
}

.zoom:hover {
	opacity: 1;
	transform: scale(1.1);
}

/* Custom CSS for tab mouseover */
.nav-tabs .nav-link:hover {
    opacity: 0.8;
    color: rgb(255 255 255);
    border-color: rgb(255 255 255);
}

.nav-tabs .nav-item .nav-link {
    opacity: 0.3;
}

.nav-tabs .nav-item .nav-link.active {
    opacity: 1.0;
}
