# Generated by Django 4.2.11 on 2024-10-14 11:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("killstats", "0004_migrate_attacker"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="general",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("basic_access", "Can access this app, Killstats."),
                    ("admin_access", "Has access to all killstats."),
                ),
            },
        ),
    ]
